<?php

namespace FiloBlu\FreeShippingOrderInfo\Plugin;

use \FiloBlu\FreeShippingOrderInfo\Model\Config\Source\Modes;

/**
 * Class SetIsFreeShippingCouponInfo
 * @package FiloBlu\FreeShippingOrderInfo\Observer
 */
class SetIsFreeShippingCouponInfo
{
    /**
     * @var string
     */
    const CODE = 'free_shipping_coupon';

    /**
     * @var \FiloBlu\FreeShippingOrderInfo\Helper\Data
     */
    protected  $_helperData;

    /**
     * SetIsFreeShippingCouponInfo constructor.
     * @param \FiloBlu\FreeShippingOrderInfo\Helper\Data $helperData
     */
    public function __construct(\FiloBlu\FreeShippingOrderInfo\Helper\Data $helperData)
    {
        $this->_helperData = $helperData;
    }

    /**
     * @param \Magento\Sales\Block\Order\Totals $totals
     * @param $area
     * @return null
     */
    public function beforeGetTotals(\Magento\Sales\Block\Order\Totals $totals, $area = null)
    {
        if ($totals->getOrder()->getIsFreeShippingCoupon() && $totals->getTotal('shipping') !== false) {

            $value = $totals->getOrder()->getCouponCode();

            $mode = $this->_helperData->getGeneralMode();

            if (empty($value)) {

                if($mode === Modes::COUPON_ONLY)
                {
                    return null;
                }

                $value = $totals->getOrder()->getDiscountDescription();
            }

            if (empty($value)) {

                if($mode === Modes::COUPON_AND_RULES)
                {
                    return null;
                }

                $value = __('Free Shipping Promo');
            }

            $totals->addTotal(new \Magento\Framework\DataObject(
                [
                    'code' => self::CODE,
                    'field' => 'is_free_shipping_coupon',
                    'value' => $value,
                    'label' => __('Free shipping coupon'),
                    'is_formated' => true
                ]
            ), 'shipping');
        }

        return null;
    }
}